@@ -93,14 +93,43 @@ repos = OrderedDict({
         'cloudmesh-mpi'
     ],
 
+    'catalog': cms + [
+        'cloudmesh-catalog'
+    ],
+
+    'slurm': cms + [
+        'cloudmesh-slurm'
+    ],
+
+    'nlp': cms + [
+        'cloudmesh-catalog',
+        'cloudmesh-nlp'
+    ],
+
+    'sbatch': cms + [
+        'cloudmesh-sbatch'
+    ],
+
+    'run': cms + [
+        'cloudmesh-run'
+    ],
+
+    'data': cms + [
+        'cloudmesh-data'
+    ],
+
+    'gpu': cms + [
+        'cloudmesh-gpu'
+    ],
+
     'cloud': cloud,
 
     'javascript': cloud + [
         'cloudmesh-javascript'
     ],
 
-    'job': cloud + [
-        'cloudmesh-job'
+    'queue': cloud + [
+        'cloudmesh-queue'
     ],
 
     'gui': cloud + [
@@ -331,11 +360,7 @@ repos = OrderedDict({
         [
             'book'
         ],
-    
-    'jobs': cms + [
-        'cloudmesh-job',
-    ],
-    
+
     'fa19-516': hostlist.expand_hostlist("fa19-516-[140-172,174]"),
 
     'fa19-523': hostlist.expand_hostlist("fa19-523-[180-196,198-212]"),
